/**
 * {}
 * @author yutent<yutent.io@gmail.com>
 * @date 2024/02/22 18:38:26
 */

/**
 * 字体里面的unicode千奇百怪有很多种形式，需要进行转换成16进制的unicode
 * 返回最终的16进制值组成的字符串
 */
export function str2unicode(str) {
  //没有管\\u的情况
  str = str.replace(/&#(x?[a-f\d]+)(;?)/gi, function (m, u) {
    let HEX_BASE = 10
    if (u.indexOf('x') === 0) {
      HEX_BASE = 16
      u = u.substr(1)
    }
    return String.fromCodePoint(parseInt(u, HEX_BASE))
  })
  //将ascii码转换成unicode
  str = str.replace(/[\x00-\xff]/g, s => `&#${s.codePointAt(0)};`)
  //将汉字转成unicode
  str = str.replace(/[^\u0000-\u00FF]/g, _ => {
    return escape(_).replace(/(%u)(\w{4})/gi, '&#x$2;')
  })
  //将十进制的unicode转换成16进制的。
  str = str.replace(/\&\#(\d+)/g, (_, n) => `&#x${(+n).toString(16)}`)

  return str
}

//驼峰转换为连字符线风格
export function hyphen(target) {
  return target.replace(/([a-z\d])([A-Z]+)/g, '$1-$2').toLowerCase()
}

//连字符转换为驼峰风格
export function camelize(target) {
  //提前判断，提高效率
  if (target.indexOf('-') < 0) {
    return target
  }
  return target.replace(/\-([a-z])/g, (m, s) => s.toUpperCase())
}

export function toUnicode(str) {
  let uArray = str2unicode(str)
  uArray = uArray.split(';')
  uArray.pop()
  return uArray.map(n => n + ';')
}

export function normalizeUnicode(str) {
  return toUnicode(str)[0]
}

export function key2underline(obj) {
  let result = {}
  for (let k in obj) {
    let v = obj[k]
    k = hyphen(k)
    result[k] = v
  }
  return result
}
